@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0104';
+our $VERSION = '0.0105';
 
 use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util MIDI-Drummer-Tiny);
 
@@ -192,7 +192,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0104
+version 0.0105
 
 =head1 SYNOPSIS
 
@@ -200,8 +200,6 @@ version 0.0104
 
   my $tabla = Music::Percussion::Tabla->new;
 
-  say $tabla->soundfont;
-
   for my $i (1 .. 3) {
       $tabla->ta;
       $tabla->ta;
@@ -209,13 +207,14 @@ version 0.0104
       $tabla->ga;
       $tabla->rest($tabla->quarter);
   }
-  $tabla->rest($tabla->whole);
+
+  say $tabla->soundfont;
 
   $tabla->timidity_conf('/tmp/timidity.cfg'); # save the cfg
   $tabla->write; # save the score as a MIDI file
 
   # OR:
-  $tabla->play_timidity; # play the MIDI with timidity
+  $tabla->play_timidity; # play the score with timidity
 
 =head1 DESCRIPTION
 
